# Matrix Documentation

Multi-Agent daTa geneRation Infra and eXperimentation framework.

## Data Synthesis

- [Online](online_synthesis.md)
- Offline
  - [LLM on Slurm](offline_synthesis/llm_slurm.md)
  - [LLM Proxy](offline_synthesis/llm_proxy.md)
  - [Inference API](offline_synthesis/inference_api.md)

## Data Processing

- [Code Verfication](code_verification.md)
- [Clustering](clustering.md)
- [Topic Classifcation](topic_classification.md)

## Evaluation
- [Evaluation](evaluation.md)

## Use Cases
- [Reasoning Data](reasoning_data.md)
